@@ -1,5 +1,5 @@
 from IPython.lib.pretty import pretty
-from lyncs_utils import compute_property, default_repr_pretty, add_kwargs_of
+from lyncs_utils import compute_property, default_repr_pretty, add_kwargs_of, add_to
 from random import random
 
 
@@ -33,6 +33,14 @@ class Foo:
         ]
 
 
+def test_add_to():
+    @add_to(Foo)
+    def added(self):
+        pass
+
+    assert hasattr(Foo, "added")
+
+
 def test_repr_pretty():
     assert pretty(Foo(10)) == "Foo(10)"
     assert pretty(Foo(10, bar="bar")) == "Foo(10, bar='bar')"
@@ -42,6 +50,8 @@ def test_repr_pretty():
 
 
 def test_compute_property():
+    assert isinstance(Foo.random, property)
+
     foo = Foo(10)
     assert foo.random == foo.random
     assert foo.random == foo._random
